All media assets in this directory are copyright © 2022 Brian Lu. They are licensed to users of
`tungsten` with a Creative Commons BY-ND 4.0 license. A copy of the license is included as a
convenience as the `LICENSE` file in this directory. A copy of this license may also be found
at https://creativecommons.org/licenses/by-nd/4.0/legalcode

![Creative Commons License](https://i.creativecommons.org/l/by-nd/4.0/88x31.png)
